@@ -125,6 +125,7 @@ def main():
             cont = (yaml.load(stream, Loader=yaml.Loader))
         except yaml.YAMLError as exc:
             print(exc)
+            exit(1)
 
     ###############################################
     # Load in data
@@ -185,7 +186,7 @@ def main():
     # Linear Inversion 
     ############################################### 
     print("Calling inversion", flush=True)
-    inv, ibreak, errn, phim, phid, mkappa, Wd, Wm, alphastar = logBarrier(KQT, np.ravel(V), T2Bins, "lcurve", MAXITER=150, sigma=np.ravel(VS), alpha=1e6, smooth="Smallest" ) 
+    inv, ibreak, errn, phim, phid, mkappa, Wd, Wm, alphastar = logBarrier(KQT, np.ravel(V), T2Bins, "lcurve", MAXITER=150, sigma=np.ravel(VS), alpha=1e7, smooth="Smallest" ) 
 
 
     ################################
@@ -295,6 +296,8 @@ def main():
                 PREc = np.reshape( prec, np.shape(V)  )
                 print("PHID linear=", errn, "PHID nonlinear=", phidc/len(np.ravel(V)))
             else:
+                nonLinearRefinement = False
+                print("Non-linear inversion failed, results will not be shown")
                 break
 
             if phidc_old - phidc/len(np.ravel(V)) < 0.005:
@@ -447,8 +450,8 @@ def main():
             ax1.set_ylim( ifaces[-1], ifaces[0] )
 
             ax2 = ax1.twiny()
-            ax2.plot( np.sum(DINV, axis=1), (ifaces[1:]+ifaces[0:-1])/2 ,  color='red' )
-            ax2.set_xlabel(u"total water (m$^3$/m$^3$)")
+            ax2.plot( np.sum(DINV, axis=1), (ifaces[1:]+ifaces[0:-1])/2 ,  color='mediumblue' )
+            ax2.set_xlabel(u"total water (m$^3$/m$^3$)", color='mediumblue')
             ax2.set_ylim( ifaces[-1], ifaces[0] )
             ax2.xaxis.set_major_locator( MaxNLocator(nbins = 3) )   
             ax2.get_xaxis().set_major_formatter(FormatStrFormatter('%0.2f'))
@@ -506,14 +509,17 @@ def main():
 
 
     ax2 = ax1.twiny()
-    ax2.plot( np.sum(INV, axis=1), (ifaces[1:]+ifaces[0:-1])/2 ,  color='red' )
-    ax2.set_xlabel(u"total water (m$^3$/m$^3$)")
+    ax2.plot( np.sum(INV, axis=1), (ifaces[1:]+ifaces[0:-1])/2 ,  color='mediumblue' )
+    ax2.set_xlabel(u"NMR total water (m$^3$/m$^3$)", color='mediumblue')
     ax2.set_ylim( ifaces[-1], ifaces[0] )
     ax2.xaxis.set_major_locator( MaxNLocator(nbins = 3) )   
     ax2.get_xaxis().set_major_formatter(FormatStrFormatter('%0.2f'))
     #ax2.axhline( y=ifaces[SNRidx], xmin=0, xmax=1, color='black', linestyle='dashed'  )
     if CalcDOI:
         ax2.axhline( y=DOI, xmin=0, xmax=1, color='black', linestyle='dashed'  )
+        
+    ax2.tick_params(axis='x', colors='mediumblue')
+    plt.setp(ax2.get_xticklabels(), color="mediumblue")
 
     plt.savefig("akvoInversion.pdf")
 
@@ -550,9 +556,10 @@ def main():
     # Only show ticks on the left and bottom spines
     ax.yaxis.set_ticks_position('left')
     ax.xaxis.set_ticks_position('bottom')   
+    plt.legend()  
  
     plt.savefig("akvoInversionWC.pdf")
-    plt.legend()  
+
     
     fr = pd.DataFrame( INV, columns=T2Bins ) #[0:-1] )
     fr.insert(0, "layer top", ifaces[0:-1] )
@@ -596,8 +603,8 @@ def main():
         #ax1.xaxis.set_label_position('top') 
 
         ax2 = ax1.twiny()
-        ax2.plot( np.sum(INVc, axis=1), (ifaces[1:]+ifaces[0:-1])/2 ,  color='red' )
-        ax2.set_xlabel(u"total water (m$^3$/m$^3$)")
+        ax2.plot( np.sum(INVc, axis=1), (ifaces[1:]+ifaces[0:-1])/2 ,  color='mediumblue' )
+        ax2.set_xlabel(u"NMR total water (m$^3$/m$^3$)", color='mediumblue')
         ax2.set_ylim( ifaces[-1], ifaces[0] )
         ax2.xaxis.set_major_locator( MaxNLocator(nbins = 3) )   
         ax2.get_xaxis().set_major_formatter(FormatStrFormatter('%0.2f'))
@@ -606,6 +613,9 @@ def main():
             ax2.axhline( y=DOI, xmin=0, xmax=1, color='black', linestyle='dashed'  )
         #ax2.xaxis.set_label_position('bottom') 
         #fig.suptitle("Non linear inversion")
+        ax2.tick_params(axis='x', colors='mediumblue')
+        plt.setp(ax2.get_xticklabels(), color="mediumblue")
+
         plt.savefig("akvoInversionNL.pdf")
 
 
